@@ -7,6 +7,7 @@ from wallarm_api.core.api.hints_api import HintsApi
 from wallarm_api.core.api.users_api import UsersApi
 from wallarm_api.core.api.vulnerabilities_api import VulnerabilitiesApi
 from wallarm_api.core.api.integrations_api import IntegrationsApi
+from wallarm_api.core.api.triggers_api import TriggersApi
 
 class Singleton(type):
     _instances = WeakValueDictionary()
@@ -33,3 +34,4 @@ class WallarmAPI(metaclass=Singleton):
         self.vulns_api = VulnerabilitiesApi(uuid, secret, host=api)
         self.integrations_api = IntegrationsApi(uuid, secret, host=api)
         self.attacks_api = AttacksApi(uuid, secret, host=api)
+        self.triggers_api = TriggersApi(uuid, secret, host=api)
